# _nichtparasoup_ ImageCrawler: Placeholders

This is an example plugin for [_nichtparasoup_](https://pypi.org/project/nichtparasoup/).  
Purpose of this project is, to give ImageCrawler plugin developers a kick start.

This project includes:
* simple demo implementation [`nichtparasoup_placeholders`](nichtparasoup_placeholders)
* _nichtparasoup_ [example config](examples)
* some **minimal** [`docs`](docs)
* rules fo static code analysis and type-checks via `mypy`
* preparation for unit tests via `pytest`
* **minimal** install script [`setup.py`](setup.py)
* some **minimal** project setup configs

For details how write a ImageCrawler plugins,
see the [dedicated docs](https://github.com/k4cg/nichtparasoup/tree/master/docs/plugin-development). 
